@@ -15,6 +15,7 @@
 package serving
 
 import (
+	"fmt"
 	"reflect"
 	"strconv"
 	"testing"
@@ -227,7 +228,7 @@ func TestUpdateConcurrencyTarget(t *testing.T) {
 	checkAnnotationValueInt(t, template, autoscaling.TargetAnnotationKey, 10)
 	// Update with invalid value
 	err = UpdateConcurrencyTarget(template, -1)
-	assert.ErrorContains(t, err, "invalid")
+	assert.ErrorContains(t, err, "should be at least 0.01")
 }
 
 func TestUpdateConcurrencyLimit(t *testing.T) {
@@ -285,21 +286,52 @@ func TestUpdateContainerArg(t *testing.T) {
 
 func TestUpdateContainerPort(t *testing.T) {
 	template, _ := getRevisionTemplate()
-	err := UpdateContainerPort(template, 8888)
-	assert.NilError(t, err)
-	// Verify update is successful or not
-	checkPortUpdate(t, template, 8888)
-	// update template with container port info
-	template.Spec.Containers[0].Ports[0].ContainerPort = 9090
-	err = UpdateContainerPort(template, 80)
-	assert.NilError(t, err)
-	// Verify that given port overrides the existing container port
-	checkPortUpdate(t, template, 80)
-}
-
-func checkPortUpdate(t *testing.T, template *servingv1.RevisionTemplateSpec, port int32) {
-	if template.Spec.Containers[0].Ports[0].ContainerPort != port {
-		t.Error("Failed to update the container port")
+	for _, tc := range []struct {
+		name    string
+		input   string
+		isErr   bool
+		expPort int32
+		expName string
+	}{{
+		name:    "only port 8888",
+		input:   "8888",
+		expPort: int32(8888),
+	}, {
+		name:    "name and port h2c:8080",
+		input:   "h2c:8080",
+		expPort: int32(8080),
+		expName: "h2c",
+	}, {
+		name:  "error case - not correct format",
+		input: "h2c:800000000000000000",
+		isErr: true,
+	}, {
+		name:  "error case - empty port",
+		input: "h2c:",
+		isErr: true,
+	}, {
+		name:  "error case - wrong format",
+		input: "8080:h2c",
+		isErr: true,
+	}, {
+		name:  "error case - multiple :",
+		input: "h2c:8080:proto",
+		isErr: true,
+	}, {
+		name:    "empty name no error",
+		input:   ":8888",
+		expPort: int32(8888),
+	}} {
+		t.Run(tc.name, func(t *testing.T) {
+			err := UpdateContainerPort(template, tc.input)
+			if tc.isErr {
+				assert.Error(t, err, fmt.Sprintf(PortFormatErr, tc.input))
+			} else {
+				assert.NilError(t, err)
+				assert.Equal(t, template.Spec.Containers[0].Ports[0].ContainerPort, tc.expPort)
+				assert.Equal(t, template.Spec.Containers[0].Ports[0].Name, tc.expName)
+			}
+		})
 	}
 }
 
@@ -638,13 +670,17 @@ func TestGenerateVolumeName(t *testing.T) {
 		"/Ab12~`!@#$%^&*()-=_+[]{}|/\\<>,./?:;\"'xZ/",
 		"",
 		"/",
+		"/path.mypath/",
+		"/.path.mypath",
 	}
 
 	expected := []string{
-		"ab12---------------------.----..-----xz",
-		"ab12---------------------.----..-----xz.",
-		"",
-		"",
+		"ab12---------------------------------xz",
+		"ab12---------------------------------xz-",
+		"k-",
+		"k-",
+		"path-mypath-",
+		"k--path-mypath",
 	}
 
 	for i := range actual {
@@ -652,6 +688,11 @@ func TestGenerateVolumeName(t *testing.T) {
 		expectedName := appendCheckSum(expected[i], actual[i])
 		assert.Equal(t, actualName, expectedName)
 	}
+
+	// 63 char limit case, no need to append the checksum in expected string
+	expName_63 := "k---ab12---------------------------------xz-ab12--------------n"
+	assert.Equal(t, len(expName_63), 63)
+	assert.Equal(t, GenerateVolumeName("/./Ab12~`!@#$%^&*()-=_+[]{}|/\\<>,./?:;\"'xZ/Ab12~`!@#$%^&*()-=_+[]{}|/\\<>,./?:;\"'xZ/"), expName_63)
 }
 
 func TestUpdateUser(t *testing.T) {
